.. include:: references.txt

.. image:: _static/gammapy_banner.png
    :width: 400px

|


Gammapy is a community-developed, open-source Python package for gamma-ray
astronomy. It is a prototype for the `CTA`_ science tools. This page
(http://docs.gammapy.org ) contains the Gammapy documentation. The Gammapy
webpage ( http://gammapy.org ) contains information about Gammapy, including
news and contact information if you have any questions, want to report and issue
or request a feature, or need help with anything Gammapy-related.

.. _gammapy_intro:

Getting started
---------------

Gammapy works with Python 2 and 3, on Linux, Mac OS X and Windows. To get
started, we recommend you follow the installation and setup instructions in
:ref:`getting-started` and then learn Gammapy via the Jupyter :ref:`tutorials`.

.. toctree::
    :maxdepth: 1

    getting-started
    tutorials
    install/index

.. _gammapy_package:

Gammapy package
---------------

As mentioned in the :ref:`getting-started`, the Gammapy package is structured as
a series of sub-packages. We recommend that you start to learn Gammapy via the
:ref:`tutorials`, and then consult the following pages for further information
about each sub-package. Those pages also contain very detailed reference
documentation for every function and class in Gammapy.

.. toctree::
    :maxdepth: 1

    data/index
    irf/index
    maps/index
    image/index
    cube/index
    detect/index
    background/index
    spectrum/index
    time/index

    stats/index
    utils/index
    scripts/index

    datasets/index
    catalog/index
    astro/index

.. _gammapy_dev:

Developer documentation
-----------------------

The Gammapy webpage contains information about the `Gammapy project and team`_
as well as information about `Gammapy contact and communication channels`_. Most
development takes place on the `Gammapy GitHub page`_.

.. toctree::
    :maxdepth: 1

    development/index

.. _Gammapy project and team: http://gammapy.org/team.html
.. _Gammapy contact and communication channels: http://gammapy.org/contact.html

References and Changelog
------------------------
.. toctree::
    :maxdepth: 1

    references
    changelog
